@@ -11,20 +11,26 @@ my $filename;
 my @child_dirs = ();
 my $show_all_matches = 0;
 my $line_breaks = 0;
+my $recursion_depth = 0;
+my $current_depth = 0;
+my $root;
+
+foreach my $index (0 .. $#ARGV) {
+  my $arg = $ARGV[$index];
 
-foreach my $arg (@ARGV) {
   if ($arg eq '--all') {
     $show_all_matches = 1;
   } elsif ($arg eq '--break') {
     $line_breaks = 1;
   } elsif ($arg eq '--help') {
     usage();
+  } elsif ($arg eq '--depth') {
+    $recursion_depth = $ARGV[$index + 1];
   } else {
     $filename = $arg;
   }
 }
 
-
 if (!$filename) {
   usage();
 }
@@ -35,15 +41,45 @@ sub usage {
     options:
 
       --all       show all matches
-      --break     print results on separate lines\n\n";
+      --break     print results on separate lines
+      --depth N   recursion depth
+      --help      show this message
+      
+Version 0.2.0.\n\n";
 
   exit;
 }
 
+sub count_depth {
+  my $output = 0;
+
+  if ($root) {
+    my $path = shift;
+    $path = $path =~ s/$root\///r;
+    my @parts = split '', $path;
+
+    for (@parts) {
+      if ($_ eq '/') {
+        $output++;
+      }
+    }
+  }
+
+  return $output;
+}
+
 sub read_dir {
   my $dir;
   my $dirname = shift;
 
+  $current_depth = count_depth $dirname;
+
+  if ($recursion_depth > 0) {
+    if ($current_depth > $recursion_depth) {
+      return;
+    }
+  }
+
   opendir($dir, $dirname) or die;
 
   my @files = readdir($dir);
@@ -76,7 +112,8 @@ sub read_dir {
 }
 
 sub run {
-  read_dir(getcwd);
+  $root = getcwd;
+  read_dir($root, 1);
 
   while (my $size = @child_dirs > 0) {
     my $dir = shift @child_dirs;
@@ -85,4 +122,3 @@ sub run {
 }
 
 1;
-
